/*!
 * \file cmdArchiver.hpp
 * \brief This file is used create archive file by command line.
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 *
 * [License]
 *
 * $id$
 */

#ifndef _CMD_ARCHIVER_H
#define _CMD_ARCHIVER_H

#include "archiveMaker.hpp"
#include "util.hpp"

/*!
 * \brief This class create archive file.
 */
class TCmdArchiver : public TArchiveMaker {
  public:
    /*!
     * \brief TCmdArchiver constructor.
     */
    TCmdArchiver(void);
    /*!
     * \brief TCmdArchiver destructor.
     */
    ~TCmdArchiver(void);
    
    /*!
     * \brief Do file archive and create archive file.
     * \param env         [in] JNI environment object.
     * \param archiveFile [in] archive file name.
     * \return Process result code of create archive.
     */
    int doArchive(JNIEnv* env, char const* archiveFile);
    
  protected:
    /*!
     * \brief Convert string separated by space to string array.
     * \param str [in] Separated string by space.
     * \return Arrayed string.<br>Don't forget deallocate.<br>
     *         Value is null, if process failure or param is illegal.
     */
    char **strToArray(char *str);
    /*!
     * \brief Execute command line.
     * \param cmdline [in] String of execute command.
     * \return Response code of execute commad line.
     */
    virtual int execute(char *cmdline);
    
};

#endif // _CMD_ARCHIVER_H
