/*
 * HeapProgressBar.java
 * Created on 2011/10/13
 * RCSID: $Id:$
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 *
 */

package jp.co.ntt.oss.heapstats.gui;

import java.awt.Color;
import java.awt.Window;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JProgressBar;
import javax.swing.border.LineBorder;

/**
 * extends {@link JDialog}<br>
 * <br>
 * In the splash window displaying the progress bar.
 */
public class HeapProgressBar extends JDialog {
    /** serialVersionUID. */
    private static final long serialVersionUID = -7185140375370777849L;

    /** A progress bar shows the execution status. */
    private JProgressBar progressBar;

    /** Set the text is understood processes running. */
    private JLabel label;

    /**
     * Create a progressbar.
     *
     * @param subtitle Know the processes running on a string
     * @param owner the owner Dialog from which the dialog is displayed or null
     *        if this dialog has no owner
     */
    public HeapProgressBar(final String subtitle, final Window owner) {
        super(owner);

        setTitle(GuiCommon.ANALYZER_TITLE);

        progressBar = new JProgressBar(0, 100);
        progressBar.setIndeterminate(true);
        progressBar.setValue(0);

        Box box = Box.createVerticalBox();
        box.setBorder(BorderFactory.createEmptyBorder(GuiCommon.BORDER_SIZE,
                GuiCommon.BORDER_SIZE, GuiCommon.BORDER_SIZE,
                GuiCommon.BORDER_SIZE));
        box.setBorder(new LineBorder(Color.BLACK));
        label = new JLabel(subtitle);
        box.add(label);
        box.add(Box.createVerticalStrut(GuiCommon.BORDER_SIZE));
        box.add(progressBar);

        box.setBackground(Color.BLACK);
        setSize(300, 45);
        add(box);
        setUndecorated(true);
        setLocationRelativeTo(owner);
    }

    /**
     * Sets the progress bar's minimum value (stored in the progress bar's data
     * model) to n.
     *
     * @param value the new minimum
     */
    public final void setValue(final int value) {
        progressBar.setIndeterminate(false);
        progressBar.setValue(value);
    }
}
