/*
 * SnapshotDateListener.java
 * Created on 2011/10/13
 * RCSID: $Id:$
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 *
 */

package jp.co.ntt.oss.heapstats.gui;

import java.awt.EventQueue;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.Vector;

import javax.swing.JComboBox;
import javax.swing.JTextField;

/**
 * implements {@link KeyListener}<br>
 * <br>
 * This class receives keyboard events to narrow the list.
 */
public class SnapshotDateListener implements
                                 KeyListener {
    /** Select Range. */
    private JComboBox dateCombo;

    /** Select Range Date List. */
    private Vector<String> snapList;

    /**
     * Creates an SnapshotDateListener to receive keyboard events.
     *
     * @param combo JComboBox
     */
    public SnapshotDateListener(final JComboBox combo) {
        dateCombo = combo;
    }

    /**
     * Sets the list of time the snapshot was taken.
     *
     * @param values List the date the snapshot was taken
     */
    public final void setSnapList(final Vector<String> values) {
        snapList = values;
    }

    @Override
    public void keyPressed(final KeyEvent keyevent) {
    }

    @Override
    public final void keyReleased(final KeyEvent keyevent) {
        if (keyevent.getKeyCode() == KeyEvent.VK_ENTER) {
            if (dateCombo.isPopupVisible()) {
                ((JTextField) keyevent.getSource()).setText(dateCombo
                        .getSelectedItem().toString());
                dateCombo.hidePopup();
            }
        }
    }

    @Override
    public final void keyTyped(final KeyEvent keyevent) {
        if (snapList == null || snapList.isEmpty()) {
            return;
        }

        EventQueue.invokeLater(new Runnable() {
            @Override
            public void run() {
                String input = ((JTextField) keyevent.getSource()).getText();

                if (input.length() == 0) {
                    dateCombo.setSelectedIndex(-1);
                } else {
                    String model = getSuggestedModel(input);
                    if (model.equals("")) {
                        dateCombo.hidePopup();
                    } else {
                        dateCombo.setSelectedIndex(snapList.indexOf(model));
                        ((JTextField) keyevent.getSource()).setText(input);
                        dateCombo.showPopup();
                    }
                }
            }
        });
    }

    /**
     * Return the string that matched the input string.
     *
     * @param text Input string
     * @return Return the matching String
     */
    private String getSuggestedModel(final String text) {
        for (String snapDate : snapList) {
            if (snapDate.startsWith(text)) {
                return snapDate;
            }
        }
        return "";
    }
}
